<no title> — BCI-Framework documentation

class `bci_framework.extensions.data_analysis.data_analysis.` `Transformers`

  Used to preprocess EEG streams.

  `centralize`(x: numpy.array, normalize: bool = False, axis: int = 0) → numpy.array

    Crentralize array.

    Remove the mean to all axis.

    Parameters

      - x – Input array of shape (channels, time).

      - normalize – Return array with maximun amplitude equal to 1.

      - axis – Axis to centralize.

    Returns

      Centralized array.

    Return type

      array